# avec test : /usr/bin/rpm -ba   --define dotests=1  $SPECS/xz....spec   2>&1  | tee   $SPECS/xz....spec.res
# sans tests: /usr/bin/rpm -ba                       $SPECS/xz....spec   2>&1  | tee   $SPECS/xz....spec.res

%{!?dotests:%define DO_TESTS 1}
%{?dotests:%define DO_TESTS 0}

Summary:LZMA compression utilities
Name:xz
Version:5.4.3
Release:1
License:LGPLv2+
Group:Applications/File
Source0:%{name}/%{name}-%{version}.tar.gz

URL:https://tukaani.org/%{name}/

BuildRequires: make
BuildRequires: gettext-devel >= 0.21-2
BuildRequires: pkg-config
BuildRequires: bash
Requires: %{name}-libs = %{version}-%{release}
Requires: bash 
Requires: gettext >= 0.21-2

%define _libdir64 %{_prefix}/lib64


%description
XZ Utils are an attempt to make LZMA compression easy to use on free (as in
freedom) operating systems. This is achieved by providing tools and libraries
which are similar to use than the equivalents of the most popular existing
compression algorithms.

LZMA is a general purpose compression algorithm designed by Igor Pavlov as
part of 7-Zip. It provides high compression ratio while keeping the
decompression speed fast.


%package libs
Summary:Libraries for decoding LZMA compression
Group:System Environment/Libraries
License:LGPLv2+
Requires: libgcc >= 10.3.0

%description libs
Libraries for decoding files compressed with LZMA or XZ utils.


%package devel
Summary:Devel libraries & headers for liblzma
Group:Development/Libraries
License:LGPLv2+
Requires:%{name}-libs = %{version}-%{release}
Requires:pkg-config

%description  devel
Devel libraries and headers for liblzma.


%package lzma-compat
Summary:Older LZMA format compatibility binaries
Group:Development/Libraries
# lz{grep,diff,more} are GPLv2+. Other binaries are LGPLv2+
License:GPLv2+ and LGPLv2+
Requires:%{name} = %{version}-%{release}
Requires: gettext  >= 0.21-2
Obsoletes: lzma < 5
Provides: lzma = 5

%description  lzma-compat
The lzma-compat package contains compatibility links for older
commands that deal with the older LZMA format.


%prep
echo "DO_TESTS=%{DO_TESTS}"
%setup -q
export PATH=/opt/freeware/bin:$PATH

# fake a <stdbool.h> as AIX5L V5.1 and XLC/C++ V7 doesn't have one
cat > stdbool.h <<EOF
// EOF
#ifndef stdbool_h_wrapper
#define stdbool_h_wrapper

typedef enum {false = 0, true = 1} bool;

#endif
EOF

# Duplicate source for 32 & 64 bits
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -rf *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit


%build
export PATH=/opt/freeware/bin:/usr/bin:/etc:/usr/sbin:/usr/bin/X11:/sbin:.
export CONFIG_SHELL=/opt/freeware/bin/bash
export CONFIG_ENV_ARGS=/opt/freeware/bin/bash
export AR="/usr/bin/ar -X32_64"
export NM="/usr/bin/nm -X32_64"
export RM="/usr/bin/rm -f"

# first build the 64-bit version
cd 64bit
export CC="/opt/freeware/bin/gcc -maix64 -O2 -D_FILE_OFFSET_BITS=64"
export CXX="/opt/freeware/bin/g++ -maix64 -O2 -D_FILE_OFFSET_BITS=64"
export OBJECT_MODE=64
export LDFLAGS="-L%{_builddir}/%{name}-%{version}/64bit/src/liblzma/.libs -L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib"


./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static

gmake

if [ "%{DO_TESTS}" == 1 ]
then
    ( gmake -k check || true )
fi
/usr/sbin/slibclean


# now build the 32-bit version
cd ../32bit
export CC="/opt/freeware/bin/gcc -maix32 -O2 -D_LARGE_FILES"
export CXX="/opt/freeware/bin/g++ -maix32 -O2 -D_LARGE_FILES"

export OBJECT_MODE=32
export LDFLAGS="-L%{_builddir}/%{name}-%{version}/32bit/src/liblzma/.libs -L/opt/freeware/lib -Wl,-bmaxdata:0x80000000 -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib"


./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static

gmake


if [ "%{DO_TESTS}" == 1 ]
then
    ( gmake -k check || true )
    /usr/sbin/slibclean
fi


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

# setup environment for 32-bit and 64-bit builds
export AR="/usr/bin/ar -X32_64"
export NM="/usr/bin/nm -X32_64"
export RM="/usr/bin/rm -f"

# install 64-bit version
cd 64bit
export OBJECT_MODE=64
gmake install DESTDIR=${RPM_BUILD_ROOT}
(
    cd  ${RPM_BUILD_ROOT}/%{_prefix}/bin
    for fic in $(ls -1| grep -v -e _32 -e _64)
    do
	mv $fic "$fic"_64
    done
)
(
    cd ${RPM_BUILD_ROOT}/%{_prefix}/bin
    ln -sf xz_64 lzcat_64
    ln -sf xzdiff_64 lzcmp_64
    ln -sf xzdiff_64 lzdiff_64
    ln -sf xzgrep_64 lzegrep_64
    ln -sf xzgrep_64 lzfgrep_64
    ln -sf xzgrep_64 lzgrep_64
    ln -sf xzless_64 lzless_64
    ln -sf xz_64 lzma_64
    ln -sf xzmore_64 lzmore_64
    ln -sf xz_64 unlzma_64
    ln -sf xz_64 unxz_64
    ln -sf xz_64 xzcat_64
    ln -sf xzdiff_64 xzcmp_64
    ln -sf xzgrep_64 xzegrep_64
    ln -sf xzgrep_64 xzfgrep_64
)

cd ../32bit
export OBJECT_MODE=32
gmake install DESTDIR=${RPM_BUILD_ROOT}
(
    cd  ${RPM_BUILD_ROOT}/%{_prefix}/bin
    for fic in $(ls -1| grep -v -e _32 -e _64)
    do
	mv $fic "$fic"_32
	ln -sf "$fic"_64 $fic
    done
)
(
    cd ${RPM_BUILD_ROOT}/%{_prefix}/bin
    ln -sf xz_32 lzcat_32
    ln -sf xzdiff_32 lzcmp_32
    ln -sf xzdiff_32 lzdiff_32
    ln -sf xzgrep_32 lzegrep_32
    ln -sf xzgrep_32 lzfgrep_32
    ln -sf xzgrep_32 lzgrep_32
    ln -sf xzless_32 lzless_32
    ln -sf xz_32 lzma_32
    ln -sf xzmore_32 lzmore_32
    ln -sf xz_32 unlzma_32
    ln -sf xz_32 unxz_32
    ln -sf xz_32 xzcat_32
    ln -sf xzdiff_32 xzcmp_32
    ln -sf xzgrep_32 xzegrep_32
    ln -sf xzgrep_32 xzfgrep_32
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -x ${RPM_BUILD_ROOT}%{_libdir64}/liblzma.a
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/liblzma.a  liblzma.so.5
(
  rm -f     ${RPM_BUILD_ROOT}%{_libdir64}/liblzma.a
  cd        ${RPM_BUILD_ROOT}%{_libdir64}
  ln -s     ../lib/liblzma.a .
)



/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

rm -rf ${RPM_BUILD_ROOT}%{_docdir}/%{name}


(
  [ -L usr/include/lzma ] && rm -f usr/include/lzma
  mkdir -p usr/include/lzma
  cd usr/include/lzma
  ln -sf ../../..%{_prefix}/include/lzma/* .
  cd -
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/AUTHORS 32bit/README 32bit/THANKS 32bit/COPYING.* 32bit/ChangeLog 
%{_bindir}/*xz*
%{_mandir}/man1/*xz*


%files libs
%defattr(-,root,system,-)
%doc 32bit/COPYING.*
%{_libdir}/*.a
%{_libdir64}/*.a


%files devel
%defattr(-,root,system,-)
%doc 32bit/doc/faq.txt 32bit/doc/lzma-file-format.txt
%doc 32bit/doc/xz-file-format.txt 32bit/doc/history.txt
%{_includedir}/lzma*
%{_libdir}/pkgconfig/liblzma.pc
%{_libdir64}/pkgconfig/liblzma.pc


%files lzma-compat
%defattr(-,root,system,-)
%{_bindir}/*lz*
%{_mandir}/man1/*lz*


%changelog
* Mon Jun 26 2023 Sangeetha Bandi<sanbandi@in.ibm.com> - 5.4.3-1
- Updated to 5.4.3

* Tue Apr 21 2020 Rishita Saha <risaha16@in.ibm.com> - 5.2.5-1
- Updated to 5.2.5

* Tue Jan 01 2019 Ravi Hirekurabar <rhirekur@in.ibm.com> - 5.2.4-1
- Updated to 5.2.4

* Fri Aug 4 2017 Reshma V Kumar <reskumar@in.ibm.com>-5.2.3-1
- Update to latest version

* Mon Aug 22 2016 Jean Girardet <jean.girardet@atos.net> - 5.2.2-2
- Manage 32/64 bits.

* Fri Aug 05 2016 Jean Girardet <jean.girardet@atos.net> - 5.2.2-1
- Initial port on AIX 6.1

* Thu Sep 06 2012 Gerard Visiedo <gerard.visiedo@bull.net> - 5.0.4-1
- Initial port on Aix6.1
